Trait ObjectStoreGetExt
Source pub trait ObjectStoreGetExt:
Display
+ Send
+ Sync
+ 'static {
// Required methods
fn get_bytes<'life0, 'life1, 'async_trait>(
&'life0 self,
src: &'life1 Path,
) -> Pin<Box<dyn Future<Output = Result<Bytes>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait;
fn exists<'life0, 'life1, 'async_trait>(
&'life0 self,
src: &'life1 Path,
) -> Pin<Box<dyn Future<Output = Result<bool>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait;
}
Return the bytes at given path in object store
Return whether an object exists at the given path.
Return the bytes at given path in object store
Return whether an object exists at the given path.